@@ -16,6 +16,30 @@ pub struct Version {
     pub variant:u8,
 }
 
+impl Version {
+    /// Constructs a Version using variant, major, minor, patch
+    pub fn make(variant:u8, major:u8, minor:u8, patch:u8) -> Self {
+        Self {
+            variant, major, minor, patch
+        }
+    }
+
+    /// Converts a Vulkan version number to a Version
+    pub fn from_vulkan_version(version: u32) -> Self {
+        Self {
+            variant: (version >> 29) as u8,
+            patch: (version & 0xfff) as u8,
+            minor: ((version >> 12) & 0x3ff) as u8,
+            major: ((version >> 22) & 0x7f) as u8,
+        }
+    }
+
+    /// Converts to a Vulkan version
+    pub fn as_vulkan_version(&self) -> u32 {
+        VK_MAKE_API_VERSION(self.variant, self.major, self.minor, self.patch)
+    }
+}
+
 impl Default for Version {
     fn default() -> Self {
         Self {
@@ -39,13 +63,3 @@ pub const fn VK_MAKE_API_VERSION(variant: u8, major:u8, minor:u8, patch:u8) -> u
     ((variant as u32) << 29) | ((major as u32) << 22) | ((minor as u32) << 12) | (patch as u32)
 }
 
-/// Converts a Vulkan version number to a Version
-pub const fn from_vulkan_version(version: u32) -> Version {
-    Version {
-        variant: (version >> 29) as u8,
-        patch: (version & 0xfff) as u8,
-        minor: ((version >> 12) & 0x3ff) as u8,
-        major: ((version >> 22) & 0x7f) as u8,
-    }
-}
-
